# RAIChU: Reaction Analysis through Imaging of Chemical Units
## Python-based informatics  tool for the visualisation of PKS chemistry
View the general.py script to learn about RAIChU's functionalities

